{% extends "admin_skel/index.html" %}

{% block content %}

<fieldset>
    <legend>Приаттаченный файл</legend>
    <form action="" method="post" onsubmit="return confirm('Удалить этот файл?')">
        <input type="hidden" name="next" value="{{ next }}"/>
        <table>
            <tbody>
                <tr>
                    <th>База данных</th>
                    <td>{{ db }}</td>
                </tr>
                <tr>
                    <th>Документ</th>
                    <td>{{ doc.id }}</td>
                </tr>
                <tr>
                    <th>Файл</th>
                    <td>{{ attachment_name }}</td>
                </tr>
                <tr>
                    <th>Размер</th>
                    <td>{{ attachment.length|filesizeformat }}</td>
                </tr>
                <tr>
                    <th>Тип</th>
                    <td>{{ attachment.content_type }}</td>
                </tr>
            </tbody>
        </table>
        <input type="submit" value="Удалить"/>
    </form>
</fieldset>
{% endblock %}
